@@ -50,7 +50,7 @@ class Exceptions:
 
 class RDSDataServiceClient:
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/rds-data.html#RDSDataService.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.75/reference/services/rds-data.html#RDSDataService.Client)
     [Show boto3-stubs documentation](./client.md)
     """
 
@@ -68,30 +68,30 @@ class RDSDataServiceClient:
         transactionId: str = None,
     ) -> BatchExecuteStatementResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/rds-data.html#RDSDataService.Client.batch_execute_statement)
-        [Show boto3-stubs documentation](./client.md#batch-execute-statement)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.75/reference/services/rds-data.html#RDSDataService.Client.batch_execute_statement)
+        [Show boto3-stubs documentation](./client.md#batch_execute_statement)
         """
 
     def begin_transaction(
         self, resourceArn: str, secretArn: str, database: str = None, schema: str = None
     ) -> BeginTransactionResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/rds-data.html#RDSDataService.Client.begin_transaction)
-        [Show boto3-stubs documentation](./client.md#begin-transaction)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.75/reference/services/rds-data.html#RDSDataService.Client.begin_transaction)
+        [Show boto3-stubs documentation](./client.md#begin_transaction)
         """
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/rds-data.html#RDSDataService.Client.can_paginate)
-        [Show boto3-stubs documentation](./client.md#can-paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.75/reference/services/rds-data.html#RDSDataService.Client.can_paginate)
+        [Show boto3-stubs documentation](./client.md#can_paginate)
         """
 
     def commit_transaction(
         self, resourceArn: str, secretArn: str, transactionId: str
     ) -> CommitTransactionResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/rds-data.html#RDSDataService.Client.commit_transaction)
-        [Show boto3-stubs documentation](./client.md#commit-transaction)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.75/reference/services/rds-data.html#RDSDataService.Client.commit_transaction)
+        [Show boto3-stubs documentation](./client.md#commit_transaction)
         """
 
     def execute_sql(
@@ -103,8 +103,8 @@ class RDSDataServiceClient:
         schema: str = None,
     ) -> ExecuteSqlResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/rds-data.html#RDSDataService.Client.execute_sql)
-        [Show boto3-stubs documentation](./client.md#execute-sql)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.75/reference/services/rds-data.html#RDSDataService.Client.execute_sql)
+        [Show boto3-stubs documentation](./client.md#execute_sql)
         """
 
     def execute_statement(
@@ -121,8 +121,8 @@ class RDSDataServiceClient:
         transactionId: str = None,
     ) -> ExecuteStatementResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/rds-data.html#RDSDataService.Client.execute_statement)
-        [Show boto3-stubs documentation](./client.md#execute-statement)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.75/reference/services/rds-data.html#RDSDataService.Client.execute_statement)
+        [Show boto3-stubs documentation](./client.md#execute_statement)
         """
 
     def generate_presigned_url(
@@ -133,14 +133,14 @@ class RDSDataServiceClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/rds-data.html#RDSDataService.Client.generate_presigned_url)
-        [Show boto3-stubs documentation](./client.md#generate-presigned-url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.75/reference/services/rds-data.html#RDSDataService.Client.generate_presigned_url)
+        [Show boto3-stubs documentation](./client.md#generate_presigned_url)
         """
 
     def rollback_transaction(
         self, resourceArn: str, secretArn: str, transactionId: str
     ) -> RollbackTransactionResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/rds-data.html#RDSDataService.Client.rollback_transaction)
-        [Show boto3-stubs documentation](./client.md#rollback-transaction)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.75/reference/services/rds-data.html#RDSDataService.Client.rollback_transaction)
+        [Show boto3-stubs documentation](./client.md#rollback_transaction)
         """
